AudioQuality enum
Supported audio capture quality presets.
Values
- auto → const AudioQuality
-
const AudioQuality(sampleRate: null, channelCount: null) - voice → const AudioQuality
-
const AudioQuality(sampleRate: 16000, channelCount: 1) - standard → const AudioQuality
-
const AudioQuality(sampleRate: 32000, channelCount: 1) - hd → const AudioQuality
-
const AudioQuality(sampleRate: 48000, channelCount: 1) - studio → const AudioQuality
-
const AudioQuality(sampleRate: 48000, channelCount: 2)
Properties
- channelCount → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int?
-
final
Methods
-
getConstraints(
String deviceId) → Map< String, dynamic> - Returns media constraints for the selected audio quality.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioQuality> - A constant List of the values in this enum, in order of their declaration.