MediaQualityModel class

Preferred audio and video capture quality used for calls.

Constructors

MediaQualityModel({required VideoQuality videoQuality, required AudioQuality audioQuality})
Creates a media quality configuration.
const

Properties

audioQuality AudioQuality
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoQuality VideoQuality
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited