VideoQuality enum
Supported video capture quality presets.
Values
- auto → const VideoQuality
-
const VideoQuality(width: null, height: null, frameRate: null) - p360 → const VideoQuality
-
const VideoQuality(width: 640, height: 360, frameRate: 30) - p480 → const VideoQuality
-
const VideoQuality(width: 854, height: 480, frameRate: 30) - p720 → const VideoQuality
-
const VideoQuality(width: 1280, height: 720, frameRate: 30) - p1080 → const VideoQuality
-
const VideoQuality(width: 1920, height: 1080, frameRate: 30) - p2k → const VideoQuality
-
const VideoQuality(width: 2560, height: 1440, frameRate: 30) - p4k → const VideoQuality
-
const VideoQuality(width: 3840, height: 2160, frameRate: 30)
Properties
- frameRate → int?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
final
Methods
-
getConstraints(
String deviceId) → Map< String, dynamic> - Returns media constraints for the selected video quality.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoQuality> - A constant List of the values in this enum, in order of their declaration.