CreateContactsControlller class
Constructors
Properties
-
currentStep
→ ValueNotifier<
int> -
final
- descriptionController → TextEditingController
-
final
- emailController → TextEditingController
-
final
-
emailControllers
→ List<
TextEditingController> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isInitialized
→ ValueNotifier<
bool> -
final
- nameController → TextEditingController
-
final
- nickNameController → TextEditingController
-
final
- phoneController → TextEditingController
-
final
-
phoneControllers
→ List<
TextEditingController> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchResults
→ ValueNotifier<
List< ContactResultModel> > -
final
-
searchType
→ ValueNotifier<
DropDownModel> -
final
-
selectedContactNotifier
→ ValueNotifier<
ContactResultModel?> -
final
-
stepOneFormKey
→ GlobalKey<
FormState> -
final
-
stepOneIsFree
→ ValueNotifier<
bool> -
final
-
stepZeroFormKey
→ GlobalKey<
FormState> -
final
-
stepZeroIsFree
→ ValueNotifier<
bool> -
final
- userIdController → TextEditingController
-
final
Methods
-
clearData(
) → void -
createContact(
BuildContext context) → Future< void> -
handleStepOne(
ValueNotifier< bool> isFree) → Future<void> -
handleStepZero(
ValueNotifier< bool> isFree) → Future<void> -
initializeData(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
searchContact(
) → Future< void> -
searchTypeOnChanged(
DropDownModel? value) → void -
selectContact(
ContactResultModel contact) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
contactSearchTypes
→ List<
DropDownModel> -
no setter