NotificationHelper class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
incomingCallNotification(
{required CallSession session, }) → void -
incomingCallsNotification(
{required List< CallSession> sessions, }) → void -
incomingGroupCallNotification(
{required GroupCallSession session, }) → void -
incomingGroupCallsNotification(
{required List< GroupCallSession> sessions, }) → void