RTCContactModel class

Constructors

RTCContactModel({required String contactUserId, required String displayName, required String nickName, String? imageUrl, required int createdOn, required int updatedOn, required String description, required List<String> emails, required List<String> phones})

Properties

contactUserId String
final
createdOn int
final
description String
getter/setter pair
displayName String
final
emails List<String>
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
final
nickName String
getter/setter pair
phones List<String>
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedOn int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

emailValidator(String? value) String?
emailValidatorNullable(String? value) String?
fromJson(Map<String, dynamic> json) RTCContactModel?
nameValidator(String? value) String?
phoneValidator(String? value) String?
phoneValidatorNullable(String? value) String?
userIdValidator(String? value) String?