CustomStepWidget class
Constructors
-
CustomStepWidget({required ThemeData theme, required int stepNumber, required String title, required dynamic onPressed(ValueNotifier<
bool> isFree), required List<Widget> body, required GlobalKey<FormState> formKey, required int currentStep, List<String> ? info, String? subtitle, String? infoBreaker, Widget? trailingWidget, String buttonText = 'NEXT', bool expandedInfo = false, List<Widget> ? extraButtons, ValueNotifier<bool> ? isFreeNotifier, bool showNextButton = true, AutovalidateMode autovalidateMode = AutovalidateMode.onUserInteraction})
Properties
- autovalidateMode → AutovalidateMode
-
final
-
body
→ List<
Widget> -
final
-
final
- currentStep → int
-
final
- expandedInfo → bool
-
final
-
extraButtons
→ List<
Widget> ? -
final
-
formKey
→ GlobalKey<
FormState> -
final
- getStep → Step
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
info
→ List<
String> ? -
final
- infoBreaker → String?
-
final
-
isFreeNotifier
→ ValueNotifier<
bool> ? -
final
-
onPressed
→ dynamic Function(ValueNotifier<
bool> isFree) -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNextButton → bool
-
final
- stepNumber → int
-
final
- subtitle → String?
-
final
- theme → ThemeData
-
final
- title → String
-
final
- trailingWidget → Widget?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited